Debian bug report logs -
#980, boring messages
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: andrew@kryten.it.com.au (Andrew Howell), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: andrew@kryten.it.com.au (Andrew Howell)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Mon, 12 Jun 1995 13:48:05 GMT
Resent-Message-ID: <debian-bugs-handler.980.061213333224810@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Mon, 12 Jun 1995 13:48:05 GMT
Received: with rfc822 via encapsulated-mail id 061213333224810;
Mon, 12 Jun 1995 13:33:33 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sL9aw-000608C; Mon, 12 Jun 95 06:31 PDT
Received: from kryten.it.com.au by pixar.com with SMTP id AA28867
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Mon, 12 Jun 1995 06:30:22 -0700
Received: by kryten.it.com.au
id <m0sL9aj-000Aa0C@kryten.it.com.au>
(Debian /\oo/\ Smail3.1.29.1 #29.32); Mon, 12 Jun 95 21:31 WST
Message-Id: <m0sL9aj-000Aa0C@kryten.it.com.au>
From: andrew@kryten.it.com.au (Andrew Howell)
To: debian-bugs@pixar.com
Date: Mon, 12 Jun 1995 21:31:44 +0800 (WST)
X-Mailer: ELM [version 2.4 PL24 PGP2]
Content-Type: text
Content-Length: 2242
Package: sysvinit, base?
Following was passed onto me by a friend
3. I make lilo choose a text mode that is 132x25. This causes my TERM
variable to be set up as con132x25. This causes problems since
there is no con132x25 terminfo file. There are a few ways to get
around this as I can see.
a) Supply terminfo files for the various text modes (Yuck :)
b) Add the word 'console' to the end of all the getty
statements in the /etc/inittab file.
e.g.
1:2345:respawn:/sbin/getty 9600 tty1 console
2:23:respawn:/sbin/getty 9600 tty2 console
3:23:respawn:/sbin/getty 9600 tty3 console
4:23:respawn:/sbin/getty 9600 tty4 console
5:23:respawn:/sbin/getty 9600 tty5 console
6:23:respawn:/sbin/getty 9600 tty6 console
rather than -
1:2345:respawn:/sbin/getty 9600 tty1
2:23:respawn:/sbin/getty 9600 tty2
3:23:respawn:/sbin/getty 9600 tty3
4:23:respawn:/sbin/getty 9600 tty4
5:23:respawn:/sbin/getty 9600 tty5
6:23:respawn:/sbin/getty 9600 tty6
c) Add a line like TERM=console;export TERM to the /etc/profile
file and other shell files.
Option a) will work but it seems like too much hassle and a waste
of disk space. Perhaps the 'untic' program should come in one of the
packages so people can easily generate their own terminfo files if
they really want to.
I think option b) is the best method. That way things work correctly
on all the VCs for all text modes.
I believe option c) isn't very a good choice. This will cause hassles
for things like running an xterm with the -ls parameter since it will
cause the TERM variable to equal console rather than xterm.
-----------------------------------------------------------------------
Dehydration - 34%, Recollection of previous evening - 2%, embarrassment
factor - 91%. Advise repair schedule:- off line for 36 hours, re-boot
startup disk, and replace head - wow, what a night!
-- Kryten in Red Dwarf `The Last Day'
Andrew Howell andrew@it.com.au
Perth, Western Australia howellaa@cs.curtin.edu.au
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: andrew@kryten.it.com.au (Andrew Howell)
Subject: Bug#980: Acknowledgement (was: no terminfo file for con132x25)
In-Reply-To: <m0sL9aj-000Aa0C@kryten.it.com.au>
References: <m0sL9aj-000Aa0C@kryten.it.com.au>
Thank you for the problem report you have sent regarding Debian GNU/Linux.
This is an automatically generated reply, to let you know your message has
been received. It is being forwarded to the developers' mailing list for
their attention; they will reply in due course.
If you wish to submit further information on your problem, please send
it to debian-bugs@pixar.com, but please ensure that the Subject
line of your message starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: iwj10@cus.cam.ac.uk (Ian Jackson), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: iwj10@cus.cam.ac.uk (Ian Jackson)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Tue, 13 Jun 1995 14:18:08 GMT
Resent-Message-ID: <debian-bugs-handler.980.061314044621177@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Tue, 13 Jun 1995 14:18:08 GMT
Received: with rfc822 via encapsulated-mail id 061314044621177;
Tue, 13 Jun 1995 14:04:47 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLW1x-0006H0C; Tue, 13 Jun 95 06:29 PDT
Received: from bootes.cus.cam.ac.uk by pixar.com with SMTP id AA15079
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Tue, 13 Jun 1995 06:27:53 -0700
Received: by bootes.cus.cam.ac.uk
(Smail-3.1.29.0 #36) id m0sLW0B-000C0CC; Tue, 13 Jun 95 14:27 BST
Received: by chiark
id <m0sLJEj-0000XRZ@chiark.al.cl.cam.ac.uk>
(Debian /\oo/\ Smail3.1.29.1 #29.32); Tue, 13 Jun 95 00:49 BST
Message-Id: <m0sLJEj-0000XRZ@chiark.al.cl.cam.ac.uk>
Date: Tue, 13 Jun 95 00:49 BST
From: iwj10@cus.cam.ac.uk (Ian Jackson)
To: linux-kernel@vger.rutgers.edu, andrew@kryten.it.com.au (Andrew Howell),
debian-bugs@pixar.com
(NB: If you wish to CC debian-bugs on any future messages on this
subject, please be sure to preserve the `Re: Bug#980' at the start of
the line so as to avoid having your message filed as a new bug
report.)
Andrew Howell writes, in Debian bug report #980:
> 3. I make lilo choose a text mode that is 132x25. This causes my TERM
> variable to be set up as con132x25. This causes problems since
> there is no con132x25 terminfo file. There are a few ways to get
> around this as I can see.
I and others have asked several times here for the default terminal
type for a Linux console to be changed to `linux'. I've even supplied
a patch (though I'm not sure whether I'm competent to do so).
Perhaps noone else thinks this is important, but I disagree. It is
causing us (Debian) several recurring problems.
I don't know why this is. Perhaps our users are more demanding.
Perhaps we're the first distribution that's worried about this kind of
thing which is trying to use and be compatible with standard
components (e.g. kernels) and at the same time trying to avoid
inserting hacks to get around avoidable brain damage.
Whatever the explanation for us in particular having problems, it
seems to me that encoding the console size into the TERM variable is a
bad idea, and that using something derived from `console' rather than
`linux' is a bad idea, and that both of these things should be fixed.
I haven't seen anyone advance any arguments against making such a
change.
Please could it be implemented ASAP. I hereby resubmit my patch,
which I believe was originally based on 1.2.0.
Ian.
--- init/main.c~ Sat Mar 18 14:24:21 1995
+++ init/main.c Thu Apr 27 01:10:24 1995
@@ -100,7 +100,7 @@
static unsigned long memory_start = 0;
static unsigned long memory_end = 0;
-static char term[21];
+static const char term[] = "TERM=linux";
int rows, cols;
int ramdisk_size;
@@ -282,7 +282,7 @@
if (!*line)
return;
args = 0;
- envs = 1; /* TERM is set to 'console' by default */
+ envs = 1; /* TERM is set to 'linux' by default */
next = line;
while ((line = next) != NULL) {
if ((next = strchr(line,' ')) != NULL)
@@ -426,7 +426,6 @@
int pid,i;
setup();
- sprintf(term, "TERM=con%dx%d", ORIG_VIDEO_COLS, ORIG_VIDEO_LINES);
#ifdef CONFIG_UMSDOS_FS
{
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: iwj10@cus.cam.ac.uk (Ian Jackson)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <m0sLJEj-0000XRZ@chiark.al.cl.cam.ac.uk>
References: <m0sLJEj-0000XRZ@chiark.al.cl.cam.ac.uk>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: Michael Weller <eowmob@exp-math.uni-essen.de>, debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: Michael Weller <eowmob@exp-math.uni-essen.de>
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 02:03:03 GMT
Resent-Message-ID: <debian-bugs-handler.980.06140149472860@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 02:03:03 GMT
Received: with rfc822 via encapsulated-mail id 06140149472860;
Wed, 14 Jun 1995 01:49:47 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLhZU-00064uC; Tue, 13 Jun 95 18:48 PDT
Received: from werner.exp-math.uni-essen.de by pixar.com with SMTP id AA27277
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Tue, 13 Jun 1995 18:47:15 -0700
Received: by werner.exp-math.uni-essen.de (AIX 3.2/UCB 5.64/2.0-expmath)
id AA79639; Wed, 14 Jun 1995 03:47:07 +0200
Date: Wed, 14 Jun 1995 03:47:07 +0200 (MSZ)
From: Michael Weller <eowmob@exp-math.uni-essen.de>
To: Andrew Howell <andrew@kryten.it.com.au>, Ian Jackson <iwj10@cus.cam.ac.uk>
Cc: linux-kernel@vger.rutgers.edu, debian-bugs@pixar.com
In-Reply-To: <9506131410.AA21932@pollux.exp-math.uni-essen.de>
Message-Id: <Pine.3.89.9506140330.C2723-0100000@werner.exp-math.uni-essen.de>
Mime-Version: 1.0
Content-Type: TEXT/PLAIN; charset=US-ASCII
> (NB: If you wish to CC debian-bugs on any future messages on this
> subject, please be sure to preserve the `Re: Bug#980' at the start of
> the line so as to avoid having your message filed as a new bug
> report.)
>
> Andrew Howell writes, in Debian bug report #980:
> > 3. I make lilo choose a text mode that is 132x25. This causes my TERM
> > variable to be set up as con132x25. This causes problems since
> > there is no con132x25 terminfo file. There are a few ways to get
> > around this as I can see.
>
> I and others have asked several times here for the default terminal
> type for a Linux console to be changed to `linux'. I've even supplied
> a patch (though I'm not sure whether I'm competent to do so).
Well.. here is a simple question: Why don't you make either your
init program (that /etc/init thingy) set TERM or even better setup
up the getty's on the console correctly to use TERM=linux. Setting TERM
in the kernel at all makes only sense if it is somehow mode depending.
If you want it static just remove it from the kernel. Such administration
details don't belong there.
You can also leave it as it is. Well setup new system can simply use
TERM=linux old system continue to run => perfect solution.
> I haven't seen anyone advance any arguments against making such a
> change.
ABove argument came up several times already. change your init
suite/setup and be happy.
Michael.
(eowmob@exp-math.uni-essen.de or eowmob@pollux.exp-math.uni-essen.de
Please do not use my vm or de0hrz1a accounts anymore. In case of real
problems reaching me try mat42b@aixrs1.hrz.uni-essen.de instead.)
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: Michael Weller <eowmob@exp-math.uni-essen.de>
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <Pine.3.89.9506140330.C2723-0100000@werner.exp-math.uni-essen.de>
References: <Pine.3.89.9506140330.C2723-0100000@werner.exp-math.uni-essen.de>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: jon@gtex02.us.es (Jon Tombs), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: jon@gtex02.us.es (Jon Tombs)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 08:48:03 GMT
Resent-Message-ID: <debian-bugs-handler.980.061408332015128@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 08:48:03 GMT
Received: with rfc822 via encapsulated-mail id 061408332015128;
Wed, 14 Jun 1995 08:33:20 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLnqq-0006H0C; Wed, 14 Jun 95 01:31 PDT
Received: from gtex02.us.es by pixar.com with SMTP id AA16330
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 01:29:35 -0700
Received: by gtex02.us.es (4.1/SMI-4.1)
id AA05620; Wed, 14 Jun 95 10:28:20 +0200
From: jon@gtex02.us.es (Jon Tombs)
Message-Id: <9506140828.AA05620@gtex02.us.es>
To: eowmob@exp-math.uni-essen.de (Michael Weller)
Date: Wed, 14 Jun 95 10:28:19 MET DST
Cc: andrew@kryten.it.com.au, iwj10@cus.cam.ac.uk,
linux-kernel@vger.rutgers.edu, debian-bugs@pixar.com
In-Reply-To: <Pine.3.89.9506140330.C2723-0100000@werner.exp-math.uni-essen.de>; from "Michael Weller" at Jun 14, 95 3:47 am
X-Mailer: ELM [version 2.3 PL11]
Michael Weller said:
>
> > I and others have asked several times here for the default terminal
> > type for a Linux console to be changed to `linux'. I've even supplied
> > a patch (though I'm not sure whether I'm competent to do so).
>
> Well.. here is a simple question: Why don't you make either your
> init program (that /etc/init thingy) set TERM or even better setup
> up the getty's on the console correctly to use TERM=linux. Setting TERM
> in the kernel at all makes only sense if it is somehow mode depending.
Why do poeple keep proposing _work rounds_ for something which is clearly
brain dead. Has any one in the don't change the random TERM variable camp got
a reason _not_ to change the current setup. Having the size in the TERM env
serves nothing, it is pointless kernel bloat. Yes you can work round it with
modified .cshrc, /bin/login /sbin/init but why kludge when we can fix! If
somebody can explain when the current TERM variable serves a purpose other
than giving new users problems please explain when!
I can't patch init on all the linux machines I use. I can patch my .bashrc, but
that doesn't stop the lusers coming up with the same problem.
Jon.
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: jon@gtex02.us.es (Jon Tombs)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <9506140828.AA05620@gtex02.us.es>
References: <9506140828.AA05620@gtex02.us.es>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: david@rem.ods.com (David Engel), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: david@rem.ods.com (David Engel)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 14:48:02 GMT
Resent-Message-ID: <debian-bugs-handler.980.061414431219993@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 14:48:02 GMT
Received: with rfc822 via encapsulated-mail id 061414431219993;
Wed, 14 Jun 1995 14:43:13 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLtd2-0005kIC; Wed, 14 Jun 95 07:41 PDT
Received: from istwok.ods.com by pixar.com with SMTP id AA29519
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 07:39:45 -0700
Received: from rem.ods.com by istwok.ods.com (4.1/SMI-4.1)
id AA14409; Wed, 14 Jun 95 09:41:16 CDT
Received: by rem.ods.com (4.1/SMI-4.1)
id AA12320; Wed, 14 Jun 95 09:42:03 CDT
From: david@rem.ods.com (David Engel)
Message-Id: <9506141442.AA12320@rem.ods.com>
To: iwj10@cus.cam.ac.uk, debian-bugs@pixar.com
Date: Wed, 14 Jun 1995 09:42:02 -0500 (CDT)
Cc: linux-kernel@vger.rutgers.edu, andrew@kryten.it.com.au,
debian-bugs@pixar.com
In-Reply-To: <m0sLJEj-0000XRZ@chiark.al.cl.cam.ac.uk> from "Ian Jackson" at Jun 13, 95 00:49:00 am
X-Mailer: ELM [version 2.4 PL23]
Content-Type: text
Content-Length: 1124
> I and others have asked several times here for the default terminal
> type for a Linux console to be changed to `linux'. I've even supplied
> a patch (though I'm not sure whether I'm competent to do so).
>
> Perhaps noone else thinks this is important, but I disagree. It is
> causing us (Debian) several recurring problems.
I'll throw in my support for changing the console to 'linux' as well.
However, unless we can persuade Linus to make the change in his
kernel, I'd prefer we change it in the Debian init or inittab. The
reason I prefer this is because I (and probably others) build my own
kernels and wouldn't want to have to apply the same patch every time I
get a new kernel from Linus.
BTW, the current /etc/termcap does not contain an entry for 'linux'.
Would whoever maintains this file please add 'linux' as an alias for
the current 'console' definition. Terminfo (aka ncurses) already
provides an entry for 'linux'.
David
--
David Engel Optical Data Systems, Inc.
david@ods.com 1101 E. Arapaho Road
(214) 234-6400 Richardson, TX 75081
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: david@rem.ods.com (David Engel)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <9506141442.AA12320@rem.ods.com>
References: <9506141442.AA12320@rem.ods.com>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>, debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 15:03:03 GMT
Resent-Message-ID: <debian-bugs-handler.980.061414541820982@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 15:03:03 GMT
Received: with rfc822 via encapsulated-mail id 061414541820982;
Wed, 14 Jun 1995 14:54:18 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLtn2-0005OXC; Wed, 14 Jun 95 07:51 PDT
Received: from keos.cs.Helsinki.FI by pixar.com with SMTP id AA29753
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 07:50:01 -0700
Received: (torvalds@localhost) by keos.cs.Helsinki.FI (8.6.10/H46) id RAA06171; Wed, 14 Jun 1995 17:50:33 +0300
Date: Wed, 14 Jun 1995 17:50:33 +0300
From: Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
Message-Id: <199506141450.RAA06171@keos.cs.Helsinki.FI>
In-Reply-To: David Engel's message as of Jun 14, 9:42
X-Mailer: Mail User's Shell (7.2.0 10/31/90)
To: david@rem.ods.com (David Engel), iwj10@cus.cam.ac.uk,
debian-bugs@pixar.com
Cc: linux-kernel@vger.rutgers.edu, andrew@kryten.it.com.au
David Engel: "Re: Bug#980: no terminfo file for con132x25" (Jun 14, 9:42):
>
> I'll throw in my support for changing the console to 'linux' as well.
> However, unless we can persuade Linus to make the change in his
> kernel, I'd prefer we change it in the Debian init or inittab.
Actually, I changed it to "linux" in my current kernel: I didn't want to
do it for the 1.2.x tree, as it _will_ break some existing setups (only
slightly, but still), but as of 1.3.2 linux have "TERM=linux" as the
initial environment.
Linus
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <199506141450.RAA06171@keos.cs.Helsinki.FI>
References: <199506141450.RAA06171@keos.cs.Helsinki.FI>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: imurdock@debian.org (Ian Murdock), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: imurdock@debian.org (Ian Murdock)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 16:48:01 GMT
Resent-Message-ID: <debian-bugs-handler.980.06141635151576@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 16:48:01 GMT
Received: with rfc822 via encapsulated-mail id 06141635151576;
Wed, 14 Jun 1995 16:35:16 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLvNd-0005nTC; Wed, 14 Jun 95 09:33 PDT
Received: from debra.debian.org by pixar.com with SMTP id AA05220
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 09:31:57 -0700
Received: by debra.debian.org
id m0sLvPF-00001xC
(Debian /\oo/\ Smail3.1.29.1 #29.31); Wed, 14 Jun 95 11:35 EST
Message-Id: <m0sLvPF-00001xC@debra.debian.org>
Date: Wed, 14 Jun 95 11:35 EST
From: imurdock@debian.org (Ian Murdock)
To: debian-bugs@pixar.com
In-Reply-To: <199506141450.RAA06171@keos.cs.Helsinki.FI> (message from Linus Torvalds on Wed, 14 Jun 1995 17:50:33 +0300)
Date: Wed, 14 Jun 1995 17:50:33 +0300
From: Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
David Engel: "Re: Bug#980: no terminfo file for con132x25" (Jun 14, 9:42):
>
> I'll throw in my support for changing the console to 'linux' as well.
> However, unless we can persuade Linus to make the change in his
> kernel, I'd prefer we change it in the Debian init or inittab.
Actually, I changed it to "linux" in my current kernel: I didn't want to
do it for the 1.2.x tree, as it _will_ break some existing setups (only
slightly, but still), but as of 1.3.2 linux have "TERM=linux" as the
initial environment.
I have just made this change to our distributed image of 1.2.10. As
Linus has changed the standard kernel sources to include this change,
future versions will not have to be patched. (Unless, of course,
there is another patch to 1.2.x, in which case I will make the change
for us.)
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: imurdock@debian.org (Ian Murdock)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <m0sLvPF-00001xC@debra.debian.org>
References: <m0sLvPF-00001xC@debra.debian.org>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: david@rem.ods.com (David Engel), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: david@rem.ods.com (David Engel)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 18:48:06 GMT
Resent-Message-ID: <debian-bugs-handler.980.06141839469528@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 18:48:06 GMT
Received: with rfc822 via encapsulated-mail id 06141839469528;
Wed, 14 Jun 1995 18:39:46 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLxKB-0005nTC; Wed, 14 Jun 95 11:37 PDT
Received: from istwok.ods.com by pixar.com with SMTP id AA13032
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 11:36:31 -0700
Received: from rem.ods.com by istwok.ods.com (4.1/SMI-4.1)
id AA18476; Wed, 14 Jun 95 13:38:15 CDT
Received: by rem.ods.com (4.1/SMI-4.1)
id AA12936; Wed, 14 Jun 95 13:39:01 CDT
From: david@rem.ods.com (David Engel)
Message-Id: <9506141839.AA12936@rem.ods.com>
To: imurdock@debian.org
Date: Wed, 14 Jun 1995 13:39:01 -0500 (CDT)
Cc: debian-bugs@pixar.com
In-Reply-To: <m0sLvPF-00001xC@debra.debian.org> from "Ian Murdock" at Jun 14, 95 11:35:00 am
X-Mailer: ELM [version 2.4 PL23]
Content-Type: text
Content-Length: 813
> Actually, I changed it to "linux" in my current kernel: I didn't want to
> do it for the 1.2.x tree, as it _will_ break some existing setups (only
> slightly, but still), but as of 1.3.2 linux have "TERM=linux" as the
> initial environment.
>
> I have just made this change to our distributed image of 1.2.10. As
> Linus has changed the standard kernel sources to include this change,
> future versions will not have to be patched. (Unless, of course,
> there is another patch to 1.2.x, in which case I will make the change
> for us.)
Don't forget that an entry for 'linux' needs to be added to
/etc/termcap.
David
--
David Engel Optical Data Systems, Inc.
david@ods.com 1101 E. Arapaho Road
(214) 234-6400 Richardson, TX 75081
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: david@rem.ods.com (David Engel)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <9506141839.AA12936@rem.ods.com>
References: <9506141839.AA12936@rem.ods.com>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent to debian-devel@pixar.com:
Subject: Bug#980: no terminfo file for con132x25
Reply-To: imurdock@debian.org (Ian Murdock), debian-bugs@pixar.com
Resent-To: debian-devel@pixar.com
Resent-From: imurdock@debian.org (Ian Murdock)
Resent-Sender: iwj10@cus.cam.ac.uk
Resent-Date: Wed, 14 Jun 1995 19:03:01 GMT
Resent-Message-ID: <debian-bugs-handler.980.061418560110222@pixar.com>
X-Debian-PR-Package: sysvinit, base?
X-Debian-PR-Keywords:
Received: via spool for debian-bugs; Wed, 14 Jun 1995 19:03:01 GMT
Received: with rfc822 via encapsulated-mail id 061418560110222;
Wed, 14 Jun 1995 18:56:01 GMT
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sLxZD-0007izC; Wed, 14 Jun 95 11:53 PDT
Received: from debra.debian.org by pixar.com with SMTP id AA13930
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Wed, 14 Jun 1995 11:52:03 -0700
Received: by debra.debian.org
id m0sLxat-00002qC
(Debian /\oo/\ Smail3.1.29.1 #29.31); Wed, 14 Jun 95 13:55 EST
Message-Id: <m0sLxat-00002qC@debra.debian.org>
Date: Wed, 14 Jun 95 13:55 EST
From: imurdock@debian.org (Ian Murdock)
To: debian-bugs@pixar.com
In-Reply-To: <9506141839.AA12936@rem.ods.com> (david@rem.ods.com)
From: david@rem.ods.com (David Engel)
Date: Wed, 14 Jun 1995 13:39:01 -0500 (CDT)
> I have just made this change to our distributed image of 1.2.10. As
> Linus has changed the standard kernel sources to include this change,
> future versions will not have to be patched. (Unless, of course,
> there is another patch to 1.2.x, in which case I will make the change
> for us.)
Don't forget that an entry for 'linux' needs to be added to
/etc/termcap.
Yes, I've done that, too.
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: imurdock@debian.org (Ian Murdock)
Subject: Bug#980: Info received (was Bug#980: no terminfo file for con132x25)
In-Reply-To: <m0sLxat-00002qC@debra.debian.org>
References: <m0sLxat-00002qC@debra.debian.org>
Thank you for the additional information you have supplied regarding
this problem report. It has been forwarded to the developers to
accompany the original report.
If you wish to continue to submit further information on your problem,
please do the same thing again: send it to debian-bugs@pixar.com, ensuring
that the Subject line starts with "Bug#980" or "Re: Bug#980" so that
we can identify it as relating to the same problem.
Please do not reply to the address at the top of this message,
unless you wish to report a problem with the bug-tracking system.
Ian Jackson
(maintainer, debian-bugs)
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: imurdock@debian.org (Ian Murdock)
In-Reply-To: <m0sP1BO-0001csC@debian.org>
References: <m0sP1BO-0001csC@debian.org> <m0sL9aj-000Aa0C@kryten.it.com.au>
Subject: Bug#980: marked as done (was: no terminfo file for con132x25)
Your message dated Fri, 23 Jun 95 00:21 EST
with message-id <m0sP1BO-0001csC@debian.org>
and subject line Bug#980:
has caused the attached bug report to be marked as done.
It is your now responsibility to ensure that the bug report is dealt
with.
(NB: If you are a system administrator and have no idea what I'm
talking about this indicates a serious mail system misconfiguration
somewhere. Please contact me immediately.)
Ian Jackson
(maintainer, debian-bugs)
Received: with rfc822 via encapsulated-mail id 061213333224810;
Mon, 12 Jun 1995 13:33:33 GMT
From kryten.it.com.au!andrew Mon Jun 12 06:31:58 1995
Return-Path: <andrew@kryten.it.com.au>
Received: from pixar.com by mongo.pixar.com with smtp
(Smail3.1.28.1 #15) id m0sL9aw-000608C; Mon, 12 Jun 95 06:31 PDT
Received: from kryten.it.com.au by pixar.com with SMTP id AA28867
(5.67b/IDA-1.5 for debian-bugs-pipe@mongo.pixar.com); Mon, 12 Jun 1995 06:30:22 -0700
Received: by kryten.it.com.au
id <m0sL9aj-000Aa0C@kryten.it.com.au>
(Debian /\oo/\ Smail3.1.29.1 #29.32); Mon, 12 Jun 95 21:31 WST
Message-Id: <m0sL9aj-000Aa0C@kryten.it.com.au>
From: andrew@kryten.it.com.au (Andrew Howell)
Subject: no terminfo file for con132x25
To: debian-bugs@pixar.com
Date: Mon, 12 Jun 1995 21:31:44 +0800 (WST)
X-Mailer: ELM [version 2.4 PL24 PGP2]
Content-Type: text
Content-Length: 2242
Package: sysvinit, base?
Following was passed onto me by a friend
3. I make lilo choose a text mode that is 132x25. This causes my TERM
variable to be set up as con132x25. This causes problems since
there is no con132x25 terminfo file. There are a few ways to get
around this as I can see.
a) Supply terminfo files for the various text modes (Yuck :)
b) Add the word 'console' to the end of all the getty
statements in the /etc/inittab file.
e.g.
1:2345:respawn:/sbin/getty 9600 tty1 console
2:23:respawn:/sbin/getty 9600 tty2 console
3:23:respawn:/sbin/getty 9600 tty3 console
4:23:respawn:/sbin/getty 9600 tty4 console
5:23:respawn:/sbin/getty 9600 tty5 console
6:23:respawn:/sbin/getty 9600 tty6 console
rather than -
1:2345:respawn:/sbin/getty 9600 tty1
2:23:respawn:/sbin/getty 9600 tty2
3:23:respawn:/sbin/getty 9600 tty3
4:23:respawn:/sbin/getty 9600 tty4
5:23:respawn:/sbin/getty 9600 tty5
6:23:respawn:/sbin/getty 9600 tty6
c) Add a line like TERM=console;export TERM to the /etc/profile
file and other shell files.
Option a) will work but it seems like too much hassle and a waste
of disk space. Perhaps the 'untic' program should come in one of the
packages so people can easily generate their own terminfo files if
they really want to.
I think option b) is the best method. That way things work correctly
on all the VCs for all text modes.
I believe option c) isn't very a good choice. This will cause hassles
for things like running an xterm with the -ls parameter since it will
cause the TERM variable to equal console rather than xterm.
-----------------------------------------------------------------------
Dehydration - 34%, Recollection of previous evening - 2%, embarrassment
factor - 91%. Advise repair schedule:- off line for 36 hours, re-boot
startup disk, and replace head - wow, what a night!
-- Kryten in Red Dwarf `The Last Day'
Andrew Howell andrew@it.com.au
Perth, Western Australia howellaa@cs.curtin.edu.au
Message sent:
From: iwj10@thor.cam.ac.uk (Ian Jackson)
To: andrew@kryten.it.com.au (Andrew Howell)
Subject: Bug#980 acknowledged by developer (was: no terminfo file for con132x25)
References: <m0sP1BO-0001csC@debian.org> <m0sL9aj-000Aa0C@kryten.it.com.au>
In-Reply-To: <m0sL9aj-000Aa0C@kryten.it.com.au>
This is an automatic notification regarding your bug report.
Responsibility for it has been taken by one of the developers, namely
imurdock@debian.org (Ian Murdock).
You should be hearing from them with a substantive response shortly, if
you have not already done so. If not, please contact them directly,
or email debian-bugs@pixar.com or myself.
Ian Jackson
(maintainer, debian-bugs)
Ian Jackson /
iwj10@thor.cam.ac.uk,
with the debian-bugs tracking mechanism